tlslite.messages.HandshakeMsg

Package tlslite :: Module messages :: Class HandshakeMsg |
[hide private]
[frames] | no frames]

# Class HandshakeMsg

source code

Known Subclasses:
  - Certificate
  - , CertificateRequest
  - , CertificateVerify
  - , ClientHello
  - , ClientKeyExchange
  - , Finished
  - , NextProtocol
  - , ServerHello
  - , ServerHelloDone
  - , ServerKeyExchange

Instance Methods | [hide private]
__init__(self, handshakeType) | source code
postWrite(self, w) | source code